Node

Struct Node 

pub struct Node {
    pub parent: AtomicCell<Option<WeakHandle>>,
    pub children: Mutex<Vec<Handle>>,
    pub data: NodeData,
}
Available on crate feature xml5ever only.
A DOM node.

Fields

parent: AtomicCell<Option<WeakHandle>>

Parent node.

children: Mutex<Vec<Handle>>

Child nodes of this node.

data: NodeData

Represents this node’s data.

Implementations

Source

impl Node

pub fn new(data: NodeData) -> Arc<Self>

Create a new node from its contents

fn get_option_element_nearest_ancestor_select(&self) -> Option<Arc<Self>>

fn parent(&self) -> Option<Weak<Self>>

fn get_a_selects_enabled_selectedcontent(&self) -> Option<Arc<Self>>

fn clone_an_option_into_selectedcontent(&self, selectedcontent: Arc<Self>)

fn clone_with_subtree(&self) -> Arc<Self>

Clones the node and all of its descendants, returning a handle to the new subtree.

This function will run into infinite recursion when the DOM tree contains cycles and it makes no attempts to guard against that.