pub struct Node {
pub parent: AtomicCell<Option<WeakHandle>>,
pub children: Mutex<Vec<Handle>>,
pub data: NodeData,
}Available on crate feature
xml5ever only.Expand description
A DOM node.
Fields
parent: AtomicCell<Option<WeakHandle>>Parent node.
children: Mutex<Vec<Handle>>Child nodes of this node.
data: NodeDataRepresents this node’s data.
Implementations
Sourceimpl Node
impl Node
Sourcefn get_option_element_nearest_ancestor_select(&self) -> Option<Arc<Self>>
fn get_option_element_nearest_ancestor_select(&self) -> Option<Arc<Self>>
fn parent(&self) -> Option<Weak<Self>>
Sourcefn get_a_selects_enabled_selectedcontent(&self) -> Option<Arc<Self>>
fn get_a_selects_enabled_selectedcontent(&self) -> Option<Arc<Self>>
Sourcefn clone_an_option_into_selectedcontent(&self, selectedcontent: Arc<Self>)
fn clone_an_option_into_selectedcontent(&self, selectedcontent: Arc<Self>)
Sourcefn clone_with_subtree(&self) -> Arc<Self>
fn clone_with_subtree(&self) -> Arc<Self>
Clones the node and all of its descendants, returning a handle to the new subtree.
This function will run into infinite recursion when the DOM tree contains cycles and it makes no attempts to guard against that.